==> jc-1.4.0.tar.gz: jas/IincInsn.h <==
// public class jas.IincInsn

// class file dependencies
// @dep_class 4697723bb1a1b8ab jas_IincInsn
// @dep_class 4062a5c70c6293f0 jas_Insn
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header jas_Insn

#include "jas/Insn.h"

#ifndef _JC_jas_IincInsn_H_
#define _JC_jas_IincInsn_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_jas_IincInsn$sub_refs	_jc_jas_IincInsn$sub_refs;
typedef struct _jc_jas_IincInsn$sub_nonrefs	_jc_jas_IincInsn$sub_nonrefs;
typedef struct _jc_jas_IincInsn$refs	_jc_jas_IincInsn$refs;
typedef struct _jc_jas_IincInsn$nonrefs	_jc_jas_IincInsn$nonrefs;
typedef struct _jc_jas_IincInsn$object	_jc_jas_IincInsn$object;

typedef const struct _jc_jas_IincInsn$vmethods	_jc_jas_IincInsn$vmethods;
typedef const struct _jc_jas_IincInsn$vtable	_jc_jas_IincInsn$vtable;
typedef const struct _jc_jas_IincInsn$vtype	_jc_jas_IincInsn$vtype;

// Constructors
extern void _jc_jas_IincInsn$method$_init$02b806c1c13eed5e(_jc_env *, struct _jc_jas_IincInsn$object *, jint, jint);

// Virtual methods structure
struct _jc_jas_IincInsn$vmethods {
};

// Vtable
struct _jc_jas_IincInsn$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jas_Insn$vmethods	jas_Insn;
	_jc_jas_IincInsn$vmethods	jas_IincInsn;
};

// Vtype
struct _jc_jas_IincInsn$vtype {
	_jc_type			type;
	_jc_jas_IincInsn$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_IincInsn$sub_refs {
};

// Reference instance fields (object)
struct _jc_jas_IincInsn$refs {
    _jc_jas_IincInsn$sub_refs	jas_IincInsn;
    _jc_jas_Insn$sub_refs	jas_Insn;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_IincInsn$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_jas_IincInsn$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jas_Insn$sub_nonrefs	jas_Insn;
    _jc_jas_IincInsn$sub_nonrefs	jas_IincInsn;
};

// Object instance structure
struct _jc_jas_IincInsn$object {
	_jc_jas_IincInsn$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_IincInsn$vtype	*vtype;
	_jc_jas_IincInsn$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_IincInsn$vtype _jc_jas_IincInsn$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_IincInsn, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_IincInsn$class_object;

#endif	/* _JC_jas_IincInsn_H_ */

==> jc-1.4.6.tar.gz: jas/IincInsn.h <==
// public class jas.IincInsn

// class file dependencies
// @dep_class 4697723bb1a1b8ab jas_IincInsn
// @dep_class 4062a5c70c6293f0 jas_Insn
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header jas_Insn

#include "jas/Insn.h"

#ifndef _JC_jas_IincInsn_H_
#define _JC_jas_IincInsn_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_jas_IincInsn$sub_refs	_jc_jas_IincInsn$sub_refs;
typedef struct _jc_jas_IincInsn$sub_nonrefs	_jc_jas_IincInsn$sub_nonrefs;
typedef struct _jc_jas_IincInsn$refs	_jc_jas_IincInsn$refs;
typedef struct _jc_jas_IincInsn$nonrefs	_jc_jas_IincInsn$nonrefs;
typedef struct _jc_jas_IincInsn$object	_jc_jas_IincInsn$object;

typedef const struct _jc_jas_IincInsn$vmethods	_jc_jas_IincInsn$vmethods;
typedef const struct _jc_jas_IincInsn$vtable	_jc_jas_IincInsn$vtable;
typedef const struct _jc_jas_IincInsn$vtype	_jc_jas_IincInsn$vtype;

// Constructors
extern void _jc_jas_IincInsn$method$_init$02b806c1c13eed5e(_jc_env *, struct _jc_jas_IincInsn$object *, jint, jint) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_jas_IincInsn$vmethods {
};

// Vtable
struct _jc_jas_IincInsn$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jas_Insn$vmethods	jas_Insn;
	_jc_jas_IincInsn$vmethods	jas_IincInsn;
};

// Vtype
struct _jc_jas_IincInsn$vtype {
	_jc_type			type;
	_jc_jas_IincInsn$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_IincInsn$sub_refs {
};

// Reference instance fields (object)
struct _jc_jas_IincInsn$refs {
    _jc_jas_IincInsn$sub_refs	jas_IincInsn;
    _jc_jas_Insn$sub_refs	jas_Insn;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_IincInsn$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_jas_IincInsn$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jas_Insn$sub_nonrefs	jas_Insn;
    _jc_jas_IincInsn$sub_nonrefs	jas_IincInsn;
};

// Object instance structure
struct _jc_jas_IincInsn$object {
	_jc_jas_IincInsn$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_IincInsn$vtype	*vtype;
	_jc_jas_IincInsn$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_IincInsn$vtype _jc_jas_IincInsn$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_IincInsn, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_IincInsn$class_object;

#endif	/* _JC_jas_IincInsn_H_ */
